package
Version:
v0.0.0-...-a1393ee
Opens a new window with list of versions in this module.
Published: Apr 14, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func StartRESTServer(application *app.App)
StartRESTServer launches the internal and public HTTP servers, blocks until
a termination signal is received, then drains connections gracefully.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.